@@ -272,11 +272,11 @@ class IotToS3Props:
         :summary: The properties for the IotToS3 class.
         '''
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = CfnTopicRuleProps(**iot_topic_rule_props)
+            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(bucket_props, dict):
-            bucket_props = BucketProps(**bucket_props)
+            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = BucketProps(**logging_bucket_props)
+            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if __debug__:
             type_hints = typing.get_type_hints(IotToS3Props.__init__)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
